==> jammo_0.6.9-3.tar.gz: jammo-0.6.9/src/chum/pen_gesture/buttons.c <==
#include <clutter/clutter.h>
#include "check_path.h"

#include "../jammo.h"
//EXIT BUTTON

static gboolean
on_rect_button_press_exit (ClutterRectangle *rect, ClutterEvent *event, gpointer data)
{
  gfloat x = 0;
  gfloat y = 0;
  clutter_event_get_coords (event, &x, &y);
  destroy_knots_buffer();

  //Should free buffer
  //g_free(global_buff[0]);
  //g_free(global_buff[1]);
  //g_free(global_buff);


  create_ink_tale();
  destroy_knots_buffer();



  clutter_actor_show(jammo_get_actor_by_id("main-menu-view"));
  clutter_actor_hide(jammo_get_actor_by_id("pen-gesture-view"));

  return TRUE; /* Stop further handling of this event. */
}

void button_exit_set(ClutterActor *stage)
{
	  gchar* directory_path1 ="/opt/jammo/password/";
	  gchar* filename1="exit.png";
	  gchar* path1 = g_build_filename (directory_path1, filename1, NULL);
	  ClutterActor *exit_btn = clutter_texture_new_from_file (path1, NULL);
	  clutter_actor_set_size (exit_btn, 87, 120);
	  clutter_actor_set_position (exit_btn, 700, 20);

	  clutter_actor_show (exit_btn);
	  clutter_container_add_actor (CLUTTER_CONTAINER (stage), exit_btn);

	  clutter_actor_set_reactive (exit_btn, TRUE);
	  g_signal_connect (exit_btn, "button-press-event", G_CALLBACK (on_rect_button_press_exit), NULL);
}


//ACTION BUTTON
/*
static gboolean
on_rect_button_press_pool (ClutterRectangle *rect, ClutterEvent *event, ClutterActor *emblem)
{
  gfloat x = 0;
  gfloat y = 0;
  clutter_event_get_coords (event, &x, &y);
  clutter_actor_animate (emblem, CLUTTER_EASE_IN_CUBIC, 1000,
		  	  	  	  	 "x", 100.0,
		  	  	  	  	 "y", 500.0,
                         "opacity", 0,
                         NULL);
  return FALSE;
}
*/
void button_action_set(ClutterActor *stage)
{
	  gchar* directory_path2 ="/opt/jammo/password/";
	  gchar* filename2="option.png";
	  gchar* path2 = g_build_filename (directory_path2, filename2, NULL);
	  ClutterActor *pool_btn = clutter_texture_new_from_file (path2, NULL);
	  clutter_actor_set_size (pool_btn, 50, 50);
	  clutter_actor_set_position (pool_btn, 700, 256);
	  clutter_actor_show (pool_btn);
	  //clutter_container_add_actor (CLUTTER_CONTAINER (stage), pool_btn);

	  clutter_actor_set_reactive (pool_btn, TRUE);
	  //g_signal_connect (pool_btn, "button-press-event", G_CALLBACK (on_rect_button_press_pool), myKnot1);

}
void button_ok_set(ClutterActor *stage)
{
	  gchar* directory_path2 ="/opt/jammo/password/";
	  gchar* filename2="ok.png";
	  gchar* path2 = g_build_filename (directory_path2, filename2, NULL);
	  ClutterActor *ok_btn = clutter_texture_new_from_file (path2, NULL);
	  clutter_actor_set_size (ok_btn, 150, 45);
	  clutter_actor_set_position (ok_btn, 565, 250);
	  clutter_actor_show (ok_btn);
	  clutter_container_add_actor (CLUTTER_CONTAINER (stage), ok_btn);

	  clutter_actor_set_reactive (ok_btn, TRUE);
	  //g_signal_connect (pool_btn, "button-press-event", G_CALLBACK (on_rect_button_press_pool), myKnot1);

}
void button_next_set(ClutterActor *stage)
{
	  gchar* directory_path2 ="/opt/jammo/password/";
	  gchar* filename2="next.png";
	  gchar* path2 = g_build_filename (directory_path2, filename2, NULL);
	  ClutterActor *next_btn = clutter_texture_new_from_file (path2, NULL);
	  clutter_actor_set_size (next_btn, 50, 50);
	  clutter_actor_set_position (next_btn, 680, 400);
	  clutter_actor_show (next_btn);
	  clutter_container_add_actor (CLUTTER_CONTAINER (stage), next_btn);

	  clutter_actor_set_reactive (next_btn, TRUE);
	  //g_signal_connect (pool_btn, "button-press-event", G_CALLBACK (on_rect_button_press_pool), myKnot1);

}
void button_back_set(ClutterActor *stage)
{
	  gchar* directory_path2 ="/opt/jammo/password/";
	  gchar* filename2="back.png";
	  gchar* path2 = g_build_filename (directory_path2, filename2, NULL);
	  ClutterActor *back_btn = clutter_texture_new_from_file (path2, NULL);
	  clutter_actor_set_size (back_btn, 50, 50);
	  clutter_actor_set_position (back_btn, 560, 400);
	  clutter_actor_show (back_btn);
	  clutter_container_add_actor (CLUTTER_CONTAINER (stage), back_btn);

	  clutter_actor_set_reactive (back_btn, TRUE);
	  //g_signal_connect (pool_btn, "button-press-event", G_CALLBACK (on_rect_button_press_pool), myKnot1);

}

void button_cancel_set(ClutterActor *stage)
{
	  gchar* directory_path2 ="/opt/jammo/password/";
	  gchar* filename2="cancel.png";
	  gchar* path2 = g_build_filename (directory_path2, filename2, NULL);
	  ClutterActor *cancel_btn = clutter_texture_new_from_file (path2, NULL);
	  clutter_actor_set_size (cancel_btn, 150, 45);
	  clutter_actor_set_position (cancel_btn, 565, 350);
	  clutter_actor_show (cancel_btn);
	  clutter_container_add_actor (CLUTTER_CONTAINER (stage), cancel_btn);

	  clutter_actor_set_reactive (cancel_btn, TRUE);
	  //g_signal_connect (pool_btn, "button-press-event", G_CALLBACK (on_rect_button_press_pool), myKnot1);

}

ClutterActor *button_avatar_set(ClutterActor *stage)
{
	  gchar* directory_path2 ="/opt/jammo/password/";
	  gchar* filename2="avatar.png";
	  gchar* path2 = g_build_filename (directory_path2, filename2, NULL);
	  ClutterActor *avatar_btn = clutter_texture_new_from_file (path2, NULL);
	  clutter_actor_set_size (avatar_btn, 50, 50);
	  clutter_actor_set_position (avatar_btn, 275, 175);
	  clutter_actor_show (avatar_btn);
	  clutter_container_add_actor (CLUTTER_CONTAINER (stage), avatar_btn);

	  clutter_actor_set_reactive (avatar_btn, TRUE);
	  //return avatar_btn;
	  //g_signal_connect (pool_btn, "button-press-event", G_CALLBACK (on_rect_button_press_pool), myKnot1);
	  return avatar_btn;
}

//CREATE NEW GESTURE BUTTON
/*
void button_new_gesture_set(ClutterActor *stage)
{
	  gchar* directory_path1 ="data";
	  gchar* filename1="new_login_green.png";
	  gchar* path1 = g_build_filename (directory_path1, filename1, NULL);
	  ClutterActor *new_btn = clutter_texture_new_from_file (path1, NULL);
	  clutter_actor_set_size (new_btn, 100, 50);
	  clutter_actor_set_position (new_btn, 600, 150);

	  clutter_actor_show (new_btn);
	  clutter_container_add_actor (CLUTTER_CONTAINER (stage), new_btn);

	  clutter_actor_set_reactive (new_btn, TRUE);
	  //g_signal_connect (exit_btn, "button-press-event", G_CALLBACK (on_rect_button_press_exit), NULL);
}
*/

==> jammo_0.6.10.tar.gz: jammo-0.6.10/src/chum/pen_gesture/buttons.c <==
#include <clutter/clutter.h>
#include "check_path.h"
#include "config.h"

#include "../jammo.h"

//EXIT BUTTON

gchar* pg_directory_path = PG_IMAGES_DIR;

static gboolean
on_rect_button_press_exit (ClutterRectangle *rect, ClutterEvent *event, gpointer data)
{
  gfloat x = 0;
  gfloat y = 0;
  clutter_event_get_coords (event, &x, &y);
  destroy_knots_buffer();

  //Should free buffer
  //g_free(global_buff[0]);
  //g_free(global_buff[1]);
  //g_free(global_buff);


  create_ink_tale();
  destroy_knots_buffer();



  clutter_actor_show(jammo_get_actor_by_id("main-menu-view"));
  clutter_actor_hide(jammo_get_actor_by_id("pen-gesture-view"));

  return TRUE; /* Stop further handling of this event. */
}

void button_exit_set(ClutterActor *stage)
{

	  gchar* filename1="exit.png";
	  gchar* path1 = g_build_filename (pg_directory_path, filename1, NULL);
	  ClutterActor *exit_btn = clutter_texture_new_from_file (path1, NULL);
	  clutter_actor_set_size (exit_btn, 87, 120);
	  clutter_actor_set_position (exit_btn, 700, 20);

	  clutter_actor_show (exit_btn);
	  clutter_container_add_actor (CLUTTER_CONTAINER (stage), exit_btn);

	  clutter_actor_set_reactive (exit_btn, TRUE);
	  g_signal_connect (exit_btn, "button-press-event", G_CALLBACK (on_rect_button_press_exit), NULL);
}


//ACTION BUTTON
/*
static gboolean
on_rect_button_press_pool (ClutterRectangle *rect, ClutterEvent *event, ClutterActor *emblem)
{
  gfloat x = 0;
  gfloat y = 0;
  clutter_event_get_coords (event, &x, &y);
  clutter_actor_animate (emblem, CLUTTER_EASE_IN_CUBIC, 1000,
		  	  	  	  	 "x", 100.0,
		  	  	  	  	 "y", 500.0,
                         "opacity", 0,
                         NULL);
  return FALSE;
}
*/
void button_action_set(ClutterActor *stage)
{

	  gchar* filename2="option.png";
	  gchar* path2 = g_build_filename (pg_directory_path, filename2, NULL);
	  ClutterActor *pool_btn = clutter_texture_new_from_file (path2, NULL);
	  clutter_actor_set_size (pool_btn, 50, 50);
	  clutter_actor_set_position (pool_btn, 700, 256);
	  clutter_actor_show (pool_btn);
	  //clutter_container_add_actor (CLUTTER_CONTAINER (stage), pool_btn);

	  clutter_actor_set_reactive (pool_btn, TRUE);
	  //g_signal_connect (pool_btn, "button-press-event", G_CALLBACK (on_rect_button_press_pool), myKnot1);

}
void button_ok_set(ClutterActor *stage)
{

	  gchar* filename2="ok.png";
	  gchar* path2 = g_build_filename (pg_directory_path, filename2, NULL);
	  ClutterActor *ok_btn = clutter_texture_new_from_file (path2, NULL);
	  clutter_actor_set_size (ok_btn, 150, 45);
	  clutter_actor_set_position (ok_btn, 565, 250);
	  clutter_actor_show (ok_btn);
	  clutter_container_add_actor (CLUTTER_CONTAINER (stage), ok_btn);

	  clutter_actor_set_reactive (ok_btn, TRUE);
	  //g_signal_connect (pool_btn, "button-press-event", G_CALLBACK (on_rect_button_press_pool), myKnot1);

}
void button_next_set(ClutterActor *stage)
{

	  gchar* filename2="next.png";
	  gchar* path2 = g_build_filename (pg_directory_path, filename2, NULL);
	  ClutterActor *next_btn = clutter_texture_new_from_file (path2, NULL);
	  clutter_actor_set_size (next_btn, 50, 50);
	  clutter_actor_set_position (next_btn, 680, 400);
	  clutter_actor_show (next_btn);
	  clutter_container_add_actor (CLUTTER_CONTAINER (stage), next_btn);

	  clutter_actor_set_reactive (next_btn, TRUE);
	  //g_signal_connect (pool_btn, "button-press-event", G_CALLBACK (on_rect_button_press_pool), myKnot1);

}
void button_back_set(ClutterActor *stage)
{

	  gchar* filename2="back.png";
	  gchar* path2 = g_build_filename (pg_directory_path, filename2, NULL);
	  ClutterActor *back_btn = clutter_texture_new_from_file (path2, NULL);
	  clutter_actor_set_size (back_btn, 50, 50);
	  clutter_actor_set_position (back_btn, 560, 400);
	  clutter_actor_show (back_btn);
	  clutter_container_add_actor (CLUTTER_CONTAINER (stage), back_btn);

	  clutter_actor_set_reactive (back_btn, TRUE);
	  //g_signal_connect (pool_btn, "button-press-event", G_CALLBACK (on_rect_button_press_pool), myKnot1);

}

void button_cancel_set(ClutterActor *stage)
{

	  gchar* filename2="cancel.png";
	  gchar* path2 = g_build_filename (pg_directory_path, filename2, NULL);
	  ClutterActor *cancel_btn = clutter_texture_new_from_file (path2, NULL);
	  clutter_actor_set_size (cancel_btn, 150, 45);
	  clutter_actor_set_position (cancel_btn, 565, 350);
	  clutter_actor_show (cancel_btn);
	  clutter_container_add_actor (CLUTTER_CONTAINER (stage), cancel_btn);

	  clutter_actor_set_reactive (cancel_btn, TRUE);
	  //g_signal_connect (pool_btn, "button-press-event", G_CALLBACK (on_rect_button_press_pool), myKnot1);

}

ClutterActor *button_avatar_set(ClutterActor *stage)
{

	  gchar* filename2="avatar.png";
	  gchar* path2 = g_build_filename (pg_directory_path, filename2, NULL);
	  ClutterActor *avatar_btn = clutter_texture_new_from_file (path2, NULL);
	  clutter_actor_set_size (avatar_btn, 50, 50);
	  clutter_actor_set_position (avatar_btn, 275, 175);
	  clutter_actor_show (avatar_btn);
	  clutter_container_add_actor (CLUTTER_CONTAINER (stage), avatar_btn);

	  clutter_actor_set_reactive (avatar_btn, TRUE);
	  //return avatar_btn;
	  //g_signal_connect (pool_btn, "button-press-event", G_CALLBACK (on_rect_button_press_pool), myKnot1);
	  return avatar_btn;
}

//CREATE NEW GESTURE BUTTON
/*
void button_new_gesture_set(ClutterActor *stage)
{
	  gchar* directory_path1 ="data";
	  gchar* filename1="new_login_green.png";
	  gchar* path1 = g_build_filename (directory_path1, filename1, NULL);
	  ClutterActor *new_btn = clutter_texture_new_from_file (path1, NULL);
	  clutter_actor_set_size (new_btn, 100, 50);
	  clutter_actor_set_position (new_btn, 600, 150);

	  clutter_actor_show (new_btn);
	  clutter_container_add_actor (CLUTTER_CONTAINER (stage), new_btn);

	  clutter_actor_set_reactive (new_btn, TRUE);
	  //g_signal_connect (exit_btn, "button-press-event", G_CALLBACK (on_rect_button_press_exit), NULL);
}
*/
